@@ -10,11 +10,21 @@ class Command(BaseCommand):
     Configure as much as possible automatically.
     """
 
-    def handle(self, *args, **kwargs):
+    def add_arguments(self, parser):
+        """Parse CLI options."""
+
+        parser.add_argument('--automate-all',
+            help="Automate all aspects of deployment?",
+            action='store_true')
+
+
+    def handle(self, *args, **options):
         # DEV: Later, this should check for the platform to deploy to.
         #   Assume deploying to Heroku for now.
         self.stdout.write("Auto-configuring project for deployment to Heroku...")
 
+        self._parse_cli_options(options)
+        self._prep_automate_all()
         self._get_heroku_app_info()
         self._set_heroku_env_var()
         self._inspect_project()
@@ -24,8 +34,57 @@ class Command(BaseCommand):
         self._check_allowed_hosts()
         self._configure_db()
         self._configure_static_files()
+        self._conclude_automate_all()
         self._show_success_message()
-    
+
+
+    def _parse_cli_options(self, options):
+        """Parse cli options."""
+        self.automate_all = options['automate_all']
+
+        if self.automate_all:
+            self.stdout.write("Automating all steps...")
+        else:
+            self.stdout.write("Only configuring for deployment...")
+
+
+    def _prep_automate_all(self):
+        """Do intial work for automating entire process."""
+        # Confirm automation.
+        # Call heroku create.
+
+        # Skip this prep work if --automate-all not used.
+        if not self.automate_all:
+            return
+
+        msg = "\n\nThe --automate-all flag means simple_deploy will:"
+        msg += "\n- Run `heroku create` for you, to create a new Heroku project;"
+        msg += "\n- Commit all changes to your project that are necessary for deployment;"
+        msg += "\n  These changes will be committed to the current branch, you"
+        msg += "\n    may want to make a new branch for this work."
+        msg += "\n- Push these changes to Heroku;"
+        msg += "\n- Run `heroku migrate` to set up the remote database;"
+        msg += "\n- Call `heroku open` to open your deployed project in a new browser tab."
+        self.stdout.write(msg)
+
+        confirmed = ''
+        while confirmed.lower() not in ('y', 'yes', 'n', 'no'):
+            prompt = "\nAre you sure you want to do this? (yes|no) "
+            confirmed = input(prompt)
+            if confirmed.lower() not in ('y', 'yes', 'n', 'no'):
+                self.stdout.write("  Please answer yes or no.")
+
+        if confirmed.lower() in ('y', 'yes'):
+            pass
+            self.stdout.write("  Running `heroku create`...")
+            subprocess.run(['heroku', 'create'])
+        else:
+            # Quit and have the user run the command again.
+            self.stdout.write("\nOkay. Canceling this run.")
+            self.stdout.write("  If you want to configure your project for deployment,")
+            self.stdout.write("  run simple_deploy again without the --automate-all flag.")
+            sys.exit()
+
 
     def _get_heroku_app_info(self):
         """Get info about the Heroku app we're pushing to."""
@@ -349,6 +408,39 @@ class Command(BaseCommand):
             self.stdout.write("    Created static files directory, and placeholder file.")
 
 
+    def _conclude_automate_all(self):
+        """Finish automating the push to Heroku."""
+        if not self.automate_all:
+            return
+
+        self.stdout.write("\n\nCommitting and pushing project...")
+
+        self.stdout.write("  Adding changes...")
+        subprocess.run(['git', 'add', '.'])
+
+        self.stdout.write("  Committing changes...")
+        subprocess.run(['git', 'commit', '-am', '"Configured project for deployment."'])
+
+        self.stdout.write("  Pushing to heroku...")
+
+        # Get the current branch name, and push that branch.
+        # Get the first line of status output, and keep everything after "On branch ".
+        git_status = subprocess.run(['git', 'status'], capture_output=True, text=True)
+        self.current_branch = git_status.stdout.split('\n')[0][10:]
+
+        self.stdout.write(f"    Pushing branch {self.current_branch}...")
+        if self.current_branch in ('main', 'master'):
+            subprocess.run(['git', 'push', 'heroku', self.current_branch])
+        else:
+            subprocess.run(['git', 'push', 'heroku', f'{self.current_branch}:main'])
+
+        self.stdout.write("  Migrating deployed app...")
+        subprocess.run(['heroku', 'run', 'python', 'manage.py', 'migrate'])
+
+        self.stdout.write("  Opening deployed app in a new browser tab...")
+        subprocess.run(['heroku', 'open'])
+
+
     def _show_success_message(self):
         """After a successful run, show a message about what to do next."""
         # DEV: This might be better structured as a block of text in a
@@ -361,21 +453,40 @@ class Command(BaseCommand):
         #   creating a new deployment.
         #   - Describe ongoing approach of commit, push, migrate. Lots to consider
         #     when doing this on production app with users, make sure you learn.
-        
-        msg = "\n\n--- Your project is now configured for deployment on Heroku. ---"
-        msg += "\n\nTo deploy your project, you will need to:"
-        msg += "\n- Commit the changes made in the configuration process."
-        msg += "\n- Push the changes to Heroku."
-        msg += "\n- Migrate the database on Heroku."
-        msg += "\n\nThe following commands should finish your initial deployment:"
-        if self.using_pipenv:
-            msg += "\n$ pipenv lock"
-        msg += "\n$ git add ."
-        msg += '\n$ git commit -am "Configured for Heroku deployment."'
-        msg += "\n$ git push heroku main"
-        msg += "\n$ heroku run python manage.py migrate"
-        msg += "\n\nAfter this, you can see your project by running 'heroku open'."
-        msg += f"\nOr, you can visit {self.heroku_app_name}.herokuapp.com."
+        if self.automate_all:
+            msg = "\n\n--- Your project should now be deployed on Heroku. ---"
+            msg += "\n\nIt should have opened up in a new browser tab."
+            msg += """\n- If you see the message "There's nothing here, yet." try waiting"""
+            msg += "\n  a moment and then refreshing your browser."
+            msg += "\n- Sometimes when the process is automated there's a little lag"
+            msg += "\n  before the project is fully deployed."
+            msg += f"\n- You can also visit your project at {self.heroku_app_name}.herokuapp.com."
+            msg += "\n\nIf you make further changes and want to push them to Heroku,"
+            msg += "\ncommit your changes and then run the following command:"
+            if self.current_branch in ('main', 'master'):
+                msg += f"\n$ git push heroku {self.current_branch}"
+            else:
+                msg += f"\n$ git push heroku {self.current_branch}:main"
+            msg += "\n\nAlso, if you haven't already done so you should review the"
+            msg += "\ndocumentation for Python deployments on Heroku at:"
+            msg += "\n- https://devcenter.heroku.com/categories/python-support"
+            msg += "\n- This documentation will help you understand how to maintain"
+            msg += "\n  your deployment."
+        else:
+            msg = "\n\n--- Your project is now configured for deployment on Heroku. ---"
+            msg += "\n\nTo deploy your project, you will need to:"
+            msg += "\n- Commit the changes made in the configuration process."
+            msg += "\n- Push the changes to Heroku."
+            msg += "\n- Migrate the database on Heroku."
+            msg += "\n\nThe following commands should finish your initial deployment:"
+            if self.using_pipenv:
+                msg += "\n$ pipenv lock"
+            msg += "\n$ git add ."
+            msg += '\n$ git commit -am "Configured for Heroku deployment."'
+            msg += "\n$ git push heroku main"
+            msg += "\n$ heroku run python manage.py migrate"
+            msg += "\n\nAfter this, you can see your project by running 'heroku open'."
+            msg += f"\nOr, you can visit {self.heroku_app_name}.herokuapp.com."
 
         self.stdout.write(msg)
 
